# -*- coding: utf-8 -*-

__version__ = '0.1.16'

from app import Kola
from blueprint import Blueprint
from kola import safe_call, safe_func, logger